pub struct WebhookRespond {
pub ack_authority: Pubkey,
pub webhook: Pubkey,
pub system_program: Pubkey,
pub worker: Pubkey,
}Expand description
Generated client accounts for WebhookRespond.
Fields
webhook: Pubkeysystem_program: Pubkeyworker: PubkeyTrait Implementations
Sourceimpl BorshSerialize for WebhookRespondwhere
Pubkey: BorshSerialize,
impl BorshSerialize for WebhookRespondwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for WebhookRespond
impl ToAccountMetas for WebhookRespond
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for WebhookRespond
impl RefUnwindSafe for WebhookRespond
impl Send for WebhookRespond
impl Sync for WebhookRespond
impl Unpin for WebhookRespond
impl UnsafeUnpin for WebhookRespond
impl UnwindSafe for WebhookRespond